.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _extending:

Extending canary
================

.. toctree::
   :maxdepth: 1

   extending.plugins
   extending.report
   extending.command
   extending.generator

.. toctree::
   :maxdepth: 1
   :caption: Common plugins:

   canary_cmake</canary_cmake/index>
   canary_gitlab</canary_gitlab/index>
   canary_hpc</canary_hpc/index>
   canary_vvtest</canary_vvtest/index>
